==> alfred-ui-native-components-0.0.99.tgz: package/ui/molecules/sliders/tripleSlider/index.tsx <==
import React, { FC, useEffect, useState } from 'react';
import { View } from 'react-native';
import { Slider } from '@miblanchard/react-native-slider';
import { BooleanIconTrack } from '../../../atoms/track/booleanIconTrack';
import { SliderModel } from '../sliderModels';
import { styles } from '../styles';

export const TripleSlider: FC<SliderModel> = ({
  ThumbComponent,
  IconLeft,
  IconRight,
  onStateChange,
  defaultValue = 1,
}) => {
  const [value, setValue] = useState<number>(defaultValue);

  useEffect(() => {
    onStateChange && onStateChange(value);
  }, [value]);

  const onFinishSlide = (val: number | number[]) => {
    const sliderValue = Array.isArray(val) ? val[0] : val;
    (sliderValue === 0 || sliderValue === 2) ? setValue(sliderValue) : setValue(1);
  };

  const handleChangeValue = (val: number | number[]) => {
    const sliderValue = Array.isArray(val) ? val[0] : val;
    setValue(sliderValue);
  };

  return (
    <View testID={'TripleSlider'}>
      <BooleanIconTrack IconLeft={IconLeft} IconRight={IconRight} />
      <Slider
        animateTransitions
        renderThumbComponent={ThumbComponent}
        trackStyle={styles.sliderTrack}
        minimumTrackTintColor={'#FFFFFF00'}
        trackClickable={false}
        minimumValue={0}
        maximumValue={2}
        value={value}
        onValueChange={handleChangeValue}
        onSlidingComplete={onFinishSlide}
        thumbTouchSize={{
          width: 40,
          height: 60,
        }}
      />
    </View>
  );
};

==> alfred-ui-native-components-0.0.159.tgz: package/ui/molecules/sliders/tripleSlider/index.tsx <==
import React, { FC, useEffect, useState } from 'react';
import { View } from 'react-native';
import { Slider } from '@miblanchard/react-native-slider';
import { BooleanIconTrack } from '../../../atoms/track/booleanIconTrack';
import { SliderModel } from '../sliderModels';
import { styles } from '../styles';

export const TripleSlider: FC<SliderModel> = ({
  ThumbComponent,
  IconLeft,
  IconRight,
  onStateChange,
  defaultValue = 1,
}) => {
  const [value, setValue] = useState<number>(defaultValue);

  useEffect(() => {
    onStateChange && onStateChange(value);
  }, [value]);

  const onFinishSlide = (val: number | number[]) => {
    const sliderValue = Array.isArray(val) ? val[0] : val;
    (sliderValue === 0 || sliderValue === 2) ? setValue(sliderValue) : setValue(1);
  };

  const handleChangeValue = (val: number | number[]) => {
    const sliderValue = Array.isArray(val) ? val[0] : val;
    setValue(sliderValue);
  };

  return (
    <View testID={'TripleSlider'}>
      <BooleanIconTrack IconLeft={IconLeft} IconRight={IconRight} />
      <Slider
        animateTransitions
        renderThumbComponent={ThumbComponent}
        trackStyle={styles().sliderTrack}
        minimumTrackTintColor={'#FFFFFF00'}
        trackClickable={false}
        minimumValue={0}
        maximumValue={2}
        value={value}
        onValueChange={handleChangeValue}
        onSlidingComplete={onFinishSlide}
        thumbTouchSize={{
          width: 40,
          height: 60,
        }}
      />
    </View>
  );
};
